@@ -43,4 +43,4 @@ debefivm-create \
 	--hook-dir="$USERADDHOOK" \
 	--customize-hook=/usr/share/autopkgtest/setup-commands/setup-testbed
 
-autopkgtest hello -- qemu --boot=efi --show-boot "$IMAGE"
+autopkgtest hello -- qemu --boot=efi --show-boot --timeout-reboot=120 "$IMAGE"
